@@ -1,6 +1,6 @@
 package App::GitGot::Command::chdir;
 BEGIN {
-  $App::GitGot::Command::chdir::VERSION = '0.9';
+  $App::GitGot::Command::chdir::VERSION = '1.0';
 }
 BEGIN {
   $App::GitGot::Command::chdir::AUTHORITY = 'cpan:GENEHACK';
@@ -17,16 +17,19 @@ sub _execute {
   my( $self, $opt, $args ) = @_;
 
   unless ( $self->active_repos and $self->active_repos == 1 ) {
-    say "You need to select a single repo";
-    exit;
+    say STDERR 'ERROR: You need to select a single repo';
+    exit(1);
   }
 
   my( $repo ) = $self->active_repos;
 
-  chdir $repo->path;
+  chdir $repo->path
+    or say STDERR "ERROR: Failed to chdir to repo ($!)" and exit(1);
+
   exec $ENV{SHELL};
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -38,7 +41,7 @@ App::GitGot::Command::chdir - open a subshell in a selected project
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
