@@ -1,6 +1,6 @@
 package App::GitGot::Command::fork;
 BEGIN {
-  $App::GitGot::Command::fork::VERSION = '0.9';
+  $App::GitGot::Command::fork::VERSION = '1.0';
 }
 BEGIN {
   $App::GitGot::Command::fork::AUTHORITY = 'cpan:GENEHACK';
@@ -12,64 +12,57 @@ extends 'App::GitGot::Command';
 use 5.010;
 
 use autodie;
+use App::GitGot::Repo::Git;
 use Cwd;
+use File::Slurp;
 use Net::GitHub::V2::Repositories;
 
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
   my $github_url = shift @$args
-    or die "Need the URL of a repo to fork!";
+    or say STDERR "ERROR: Need the URL of a repo to fork!" and exit(1);
 
   my( $user , $pass ) = _parse_github_identity();
 
   my( $owner , $repo_name ) = _parse_github_url( $github_url );
 
-  my $repo = Net::GitHub::V2::Repositories->new(
+  Net::GitHub::V2::Repositories->new(
     owner => $owner ,
     repo  => $repo_name ,
     login => $user ,
     token => $pass ,
-  );
-
-  $repo->fork; ## hardcore forking action!
+  )->fork; ## hardcore forking action!
 
   my $new_repo_url = $github_url;
   $new_repo_url =~ s/$owner/$user/;
 
-  my $cwd = cwd();
-
-  my $entry = {
+  my $new_repo = App::GitGot::Repo::Git->new({ entry => {
     name => $repo_name ,
-    path => "$cwd/$repo_name" ,
+    path => cwd() . "/$repo_name" ,
     repo => $new_repo_url ,
     type => 'git' ,
-  };
-  my $new_repo = App::GitGot::Repo->new({ entry => $entry });
+  }});
+
   $self->add_repo( $new_repo );
   $self->write_config;
 }
 
 sub _parse_github_identity {
   my $file = "$ENV{HOME}/.github-identity";
-  die "Can't find ~/.github-identity"
-    unless -e $file;
 
-  open( my $IN , '<' , $file );
-  my @lines = <$IN>;
-  close( $IN );
+  -e $file or
+    say STDERR "ERROR: Can't find $ENV{HOME}/.github-identity" and exit(1);
 
-  my %config;
-  foreach ( @lines ) {
-    my( $key , $value ) = split /\s/;
-    $config{$key} = $value;
-  }
+  my @lines = read_file( $file );
+
+  my %config = map { my( @x ) = split /\s/; { $x[0] => $x[1] } } @lines;
 
   my $user = $config{login}
-    or die "Couldn't parse login info from ~/.github_identity";
+    or say STDERR "Couldn't parse login info from ~/.github_identity" and exit(1);
 
   my $pass = $config{token}
-    or die "Couldn't parse token info from ~/.github_identity";
+    or say STDERR "Couldn't parse token info from ~/.github_identity" and exit(1);
 
   return( $user , $pass );
 }
@@ -77,12 +70,13 @@ sub _parse_github_identity {
 sub _parse_github_url {
   my $url = shift;
 
-  die "Can't parse that"
-    unless $url =~ m|/github.com/([^/]+)/([^/]+).git$|;
+  my( $owner , $repo ) = $url =~ m|/github.com/([^/]+)/([^/]+).git$|
+    or say STDERR "ERROR: Can't parse '$url'" and exit(1);
 
-  return( $1 , $2 );
+  return( $owner , $repo );
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -94,7 +88,7 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
