@@ -1,6 +1,6 @@
 package App::GitGot::Command::list;
 BEGIN {
-  $App::GitGot::Command::list::VERSION = '0.9';
+  $App::GitGot::Command::list::VERSION = '1.0';
 }
 BEGIN {
   $App::GitGot::Command::list::AUTHORITY = 'cpan:GENEHACK';
@@ -20,23 +20,24 @@ sub _execute {
 
   for my $repo ( $self->active_repos ) {
     my $repo_remote = ( $repo->repo and -d $repo->path ) ? $repo->repo
-      : ( $repo->repo ) ? $repo->repo . ' (Not checked out)'
-        : ( -d $repo->path ) ? 'NO REMOTE'
-          : 'ERROR: No remote and no repo?!';
-
-    my $msg = sprintf "%-${max_len}s  %-4s  %s\n",
-      $repo->label, $repo->type, $repo_remote;
+      : ( $repo->repo )    ? $repo->repo . ' (Not checked out)'
+      : ( -d $repo->path ) ? 'NO REMOTE'
+      : 'ERROR: No remote and no repo?!';
 
     printf "%3d) ", $repo->number;
 
     if ( $self->quiet ) { say $repo->label }
-    elsif ( $self->verbose ) {
-      printf "$msg    tags: %s\n" , $repo->tags;
+    else {
+      printf "%-${max_len}s  %-4s  %s\n",
+        $repo->label, $repo->type, $repo_remote;
+      if ( $self->verbose ) {
+        printf "    tags: %s\n" , $repo->tags if $repo->tags;
+      }
     }
-    else { print $msg}
   }
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -48,7 +49,7 @@ App::GitGot::Command::list - list managed repositories
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
