@@ -1,9 +1,9 @@
-package App::GitGot::Outputter::Dark;
+package App::GitGot::Outputter::dark;
 BEGIN {
-  $App::GitGot::Outputter::Dark::VERSION = '0.9';
+  $App::GitGot::Outputter::dark::VERSION = '1.0';
 }
 BEGIN {
-  $App::GitGot::Outputter::Dark::AUTHORITY = 'cpan:GENEHACK';
+  $App::GitGot::Outputter::dark::AUTHORITY = 'cpan:GENEHACK';
 }
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
 
@@ -20,7 +20,7 @@ has 'color_error' => (
 has 'color_warning' => (
   is      => 'ro' ,
   isa     => 'Str' ,
-  default => 'bold black on_bright_yellow'
+  default => 'bold black on_yellow'
 );
 
 has 'color_major_change' => (
@@ -36,17 +36,18 @@ has 'color_minor_change' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+1;
 
 __END__
 =pod
 
 =head1 NAME
 
-App::GitGot::Outputter::Dark - Color scheme appropriate for dark terminal backgrounds
+App::GitGot::Outputter::dark - Color scheme appropriate for dark terminal backgrounds
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
