@@ -1,6 +1,6 @@
 package App::GitGot::Outputter::light;
 BEGIN {
-  $App::GitGot::Outputter::light::VERSION = '0.9';
+  $App::GitGot::Outputter::light::VERSION = '1.0';
 }
 BEGIN {
   $App::GitGot::Outputter::light::AUTHORITY = 'cpan:GENEHACK';
@@ -17,6 +17,9 @@ has 'color_error' => (
   default => 'bold red'
 );
 
+# Color choices by drdrang based on a conversation that started with
+# <http://www.leancrew.com/all-this/2010/12/batch-comparison-of-git-repositories/>
+
 has 'color_warning' => (
   is      => 'ro' ,
   isa     => 'Str' ,
@@ -36,6 +39,7 @@ has 'color_minor_change' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+1;
 
 __END__
 =pod
@@ -46,7 +50,7 @@ App::GitGot::Outputter::light - Color scheme appropriate for dark terminal backg
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
